@@ -125,7 +125,6 @@ from ._jsii import *
 from .aws_arch import (
     DrawioAws4ParentShapes as _DrawioAws4ParentShapes_a140e9a5,
     DrawioAwsResourceIconStyleBase as _DrawioAwsResourceIconStyleBase_9b406fcd,
-    ThemesEnum as _ThemesEnum_7a7c4e43,
 )
 from .aws_arch.drawio_spec.aws4 import ShapeNames as _ShapeNames_b18b2fa9
 from .aws_arch.pricing_manifest import Service as _Service_4bf9f4e8
@@ -146,7 +145,7 @@ class AwsArchitecture(
         cls,
         qualified_asset_key: builtins.str,
         format: builtins.str,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> builtins.str:
         '''(experimental) Gets formatted asset path including extension and theme.
 
@@ -159,7 +158,7 @@ class AwsArchitecture(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsArchitecture.format_asset_path)
+            type_hints = typing.get_type_hints(_typecheckingstub__50cb6e377ace030d7d0fd23b8b75ce7cab047e065aff0f335dd00cc536e0b731)
             check_type(argname="argument qualified_asset_key", value=qualified_asset_key, expected_type=type_hints["qualified_asset_key"])
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
@@ -176,7 +175,7 @@ class AwsArchitecture(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsArchitecture.get_category)
+            type_hints = typing.get_type_hints(_typecheckingstub__15d698581bce0a553107193aec703873d21ff56d3a1277980fcbac4037de42f7)
             check_type(argname="argument category", value=category, expected_type=type_hints["category"])
         return typing.cast("AwsCategory", jsii.sinvoke(cls, "getCategory", [category]))
 
@@ -186,7 +185,7 @@ class AwsArchitecture(
         cls,
         instance_type: builtins.str,
         format: typing.Optional[builtins.str] = None,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> builtins.str:
         '''(experimental) Get icon for EC2 instance type.
 
@@ -199,12 +198,37 @@ class AwsArchitecture(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsArchitecture.get_instance_type_icon)
+            type_hints = typing.get_type_hints(_typecheckingstub__62420b3b4e6499da381320d0dffe1ae40fbfba93826daf27b7b9e7a9812533b7)
             check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getInstanceTypeIcon", [instance_type, format, theme]))
 
+    @jsii.member(jsii_name="getRdsInstanceTypeIcon")
+    @builtins.classmethod
+    def get_rds_instance_type_icon(
+        cls,
+        instance_type: builtins.str,
+        format: typing.Optional[builtins.str] = None,
+        theme: typing.Optional[builtins.str] = None,
+    ) -> builtins.str:
+        '''(experimental) Get icon for RDS instance type.
+
+        :param instance_type: - The {@link AwsAsset.RdsInstanceType} to get icon for.
+        :param format: - The format of icon.
+        :param theme: - Optional theme.
+
+        :return: Returns relative asset icon path
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__643e13aebfc6b58e52fa31f8c1461ad88e54493f25b2a511448723eced639c43)
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument format", value=format, expected_type=type_hints["format"])
+            check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
+        return typing.cast(builtins.str, jsii.sinvoke(cls, "getRdsInstanceTypeIcon", [instance_type, format, theme]))
+
     @jsii.member(jsii_name="getResource")
     @builtins.classmethod
     def get_resource(cls, cfn_type: builtins.str) -> "AwsResource":
@@ -216,7 +240,7 @@ class AwsArchitecture(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsArchitecture.get_resource)
+            type_hints = typing.get_type_hints(_typecheckingstub__ed6a924b8cfa08bf04a82f31554030fb1973ca30c773d78c32679c51b30554c5)
             check_type(argname="argument cfn_type", value=cfn_type, expected_type=type_hints["cfn_type"])
         return typing.cast("AwsResource", jsii.sinvoke(cls, "getResource", [cfn_type]))
 
@@ -231,10 +255,24 @@ class AwsArchitecture(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsArchitecture.get_service)
+            type_hints = typing.get_type_hints(_typecheckingstub__8104b4fced639cf6dbccebcf36b75834b302371e6ac70e1fc09dacfc0c7671d3)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
         return typing.cast("AwsService", jsii.sinvoke(cls, "getService", [identifier]))
 
+    @jsii.member(jsii_name="parseAssetPath")
+    @builtins.classmethod
+    def parse_asset_path(cls, asset_path: builtins.str) -> "ParsedAssetKey":
+        '''(experimental) Parse assets path into part descriptor.
+
+        :param asset_path: - Absolute or relative asset file path to parse.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__69679a6460ffe74dd94019acc30bcd926f5c390f7b5469015e3db7434076eb84)
+            check_type(argname="argument asset_path", value=asset_path, expected_type=type_hints["asset_path"])
+        return typing.cast("ParsedAssetKey", jsii.sinvoke(cls, "parseAssetPath", [asset_path]))
+
     @jsii.member(jsii_name="resolveAssetPath")
     @builtins.classmethod
     def resolve_asset_path(cls, asset_path: builtins.str) -> builtins.str:
@@ -245,12 +283,32 @@ class AwsArchitecture(
         :return: Absolute asset path
 
         :stability: experimental
+        :throws: Error if asset path is not relative
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsArchitecture.resolve_asset_path)
+            type_hints = typing.get_type_hints(_typecheckingstub__552d38a0aeee02653237862f4fec1793b69ed0bc3bccaba88dd9d8c8a5ade0ca)
             check_type(argname="argument asset_path", value=asset_path, expected_type=type_hints["asset_path"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "resolveAssetPath", [asset_path]))
 
+    @jsii.member(jsii_name="resolveAssetSvgDataUrl")
+    @builtins.classmethod
+    def resolve_asset_svg_data_url(cls, svg_asset_path: builtins.str) -> builtins.str:
+        '''(experimental) Resolve relative asset path as SVG `Data URL <https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URLs>`_.
+
+        ``data:image/svg+xml;base64,...``
+
+        :param svg_asset_path: - The relative path of svg asset to resolve.
+
+        :return: SVG `Data URL <https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URLs>`_
+
+        :stability: experimental
+        :throws: Error if path is not svg
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9a7e93f3c9b45f20b0f66b8a67bd69838434582f2b9954d1dc836dc586c103ee)
+            check_type(argname="argument svg_asset_path", value=svg_asset_path, expected_type=type_hints["svg_asset_path"])
+        return typing.cast(builtins.str, jsii.sinvoke(cls, "resolveAssetSvgDataUrl", [svg_asset_path]))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="assetDirectory")
     def asset_directory(cls) -> builtins.str:
@@ -312,7 +370,7 @@ class AwsCategory(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCategory.get_category)
+            type_hints = typing.get_type_hints(_typecheckingstub__bf6ff8b962606b7b17ab54feb5db42cfbce8166becc3c94ca2be14691fe2e5c4)
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast("AwsCategory", jsii.sinvoke(cls, "getCategory", [id]))
 
@@ -328,7 +386,7 @@ class AwsCategory(
     def icon(
         self,
         format: builtins.str,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> typing.Optional[builtins.str]:
         '''(experimental) Retrieves a well-formatted relative path to the icon for this given category in the specified format.
 
@@ -338,7 +396,7 @@ class AwsCategory(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCategory.icon)
+            type_hints = typing.get_type_hints(_typecheckingstub__f69a17317b51c33fb0068a46d7feef91b78aa33a2b43000fb364b396976fc3e5)
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "icon", [format, theme]))
@@ -474,7 +532,7 @@ class AwsCategoryDrawioStyles(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCategoryDrawioStyles.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ae148133bd9290873b5fcadeb1785d89474cf6a8babeb3b4249a70e923f18893)
             check_type(argname="argument category_shape", value=category_shape, expected_type=type_hints["category_shape"])
         base = _DrawioAwsResourceIconStyleBase_9b406fcd(
             fill_color=fill_color,
@@ -510,7 +568,7 @@ class AwsCategoryDrawioStyles(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCategoryDrawioStyles.get_resource_style)
+            type_hints = typing.get_type_hints(_typecheckingstub__59b952a871d610dd7d5e35974c586091f08905f704b7425d9ce8953c5830a506)
             check_type(argname="argument resource_shape", value=resource_shape, expected_type=type_hints["resource_shape"])
         return typing.cast("AwsDrawioShapeStyle", jsii.invoke(self, "getResourceStyle", [resource_shape]))
 
@@ -528,7 +586,7 @@ class AwsCategoryDrawioStyles(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCategoryDrawioStyles.get_service_style)
+            type_hints = typing.get_type_hints(_typecheckingstub__8c15f9fc8e1d6209bd88b50e8dfebc38c9a2f8e97f9ad58c1c05728286593464)
             check_type(argname="argument service_shape", value=service_shape, expected_type=type_hints["service_shape"])
         return typing.cast("AwsDrawioResourceIconStyle", jsii.invoke(self, "getServiceStyle", [service_shape]))
 
@@ -626,7 +684,7 @@ class AwsDrawioResourceIconStyle(_DrawioAwsResourceIconStyleBase_9b406fcd):
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsDrawioResourceIconStyle.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b919eb9ba02a70d639eb21b33dcab74c41350024fbd48ce9c86f21461f99f6d7)
             check_type(argname="argument align", value=align, expected_type=type_hints["align"])
             check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
             check_type(argname="argument dashed", value=dashed, expected_type=type_hints["dashed"])
@@ -644,7 +702,7 @@ class AwsDrawioResourceIconStyle(_DrawioAwsResourceIconStyleBase_9b406fcd):
             check_type(argname="argument gradient_color", value=gradient_color, expected_type=type_hints["gradient_color"])
             check_type(argname="argument res_icon", value=res_icon, expected_type=type_hints["res_icon"])
             check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "align": align,
             "aspect": aspect,
             "dashed": dashed,
@@ -894,7 +952,7 @@ class AwsDrawioShapeStyle(_DrawioAwsResourceIconStyleBase_9b406fcd):
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsDrawioShapeStyle.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__0557897d78e40b40ed7072ae513a2fc9ce846dd39b11d3011e4a2f9fb46ddf46)
             check_type(argname="argument align", value=align, expected_type=type_hints["align"])
             check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
             check_type(argname="argument dashed", value=dashed, expected_type=type_hints["dashed"])
@@ -911,7 +969,7 @@ class AwsDrawioShapeStyle(_DrawioAwsResourceIconStyleBase_9b406fcd):
             check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
             check_type(argname="argument gradient_color", value=gradient_color, expected_type=type_hints["gradient_color"])
             check_type(argname="argument shape", value=shape, expected_type=type_hints["shape"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "align": align,
             "aspect": aspect,
             "dashed": dashed,
@@ -1106,7 +1164,7 @@ class AwsResource(
         :throws: Error is no resource found
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsResource.find_resource)
+            type_hints = typing.get_type_hints(_typecheckingstub__443f82bc75854974ef25affe3c77395efc6eafc27d3e89b2b90094ce7f85651e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(typing.Optional["AwsResource"], jsii.sinvoke(cls, "findResource", [value]))
 
@@ -1121,7 +1179,7 @@ class AwsResource(
         :throws: Error is no resource found
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsResource.get_resource)
+            type_hints = typing.get_type_hints(_typecheckingstub__c74598595ef87eb3d32bc607c61c8ff2ee5cdea295c85f48b84e2deabd2d34b0)
             check_type(argname="argument cfn_resource_type", value=cfn_resource_type, expected_type=type_hints["cfn_resource_type"])
         return typing.cast("AwsResource", jsii.sinvoke(cls, "getResource", [cfn_resource_type]))
 
@@ -1133,23 +1191,69 @@ class AwsResource(
         '''
         return typing.cast(typing.Optional[AwsDrawioShapeStyle], jsii.invoke(self, "drawioStyle", []))
 
-    @jsii.member(jsii_name="getResourceIcon")
-    def get_resource_icon(
+    @jsii.member(jsii_name="getCategoryIcon")
+    def get_category_icon(
         self,
         format: builtins.str,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> typing.Optional[builtins.str]:
-        '''(experimental) Gets the resource specific icon for the resource.
+        '''(experimental) Gets the category icon for the resource.
+
+        This maybe different than {@link AwsResource.service.category.icon} based on mappings overrides, which
+        if do not exist will fallback to {@link AwsResource.service.category.icon}.
 
         :param format: - The format of icon.
         :param theme: - Optional theme.
 
         :return: Returns relative asset icon path
 
+        :see: {@link AwsService.icon}
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsResource.get_resource_icon)
+            type_hints = typing.get_type_hints(_typecheckingstub__bbaa927bc3fbe72a481a61f7b9d4f4189cc6b988530ea58b37bb4a085a50c557)
+            check_type(argname="argument format", value=format, expected_type=type_hints["format"])
+            check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
+        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getCategoryIcon", [format, theme]))
+
+    @jsii.member(jsii_name="getGeneralIcon")
+    def get_general_icon(
+        self,
+        format: builtins.str,
+        theme: typing.Optional[builtins.str] = None,
+    ) -> typing.Optional[builtins.str]:
+        '''(experimental) Gets the general icon for the resource if available.
+
+        :param format: - The format of icon.
+        :param theme: - Optional theme.
+
+        :return: Returns relative asset icon path or undefined if does not have general icon
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__d91c975bb6d0cf335b8a7e464ecee297e8ca1409c582dafcf7b6a6233c7813e9)
+            check_type(argname="argument format", value=format, expected_type=type_hints["format"])
+            check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
+        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getGeneralIcon", [format, theme]))
+
+    @jsii.member(jsii_name="getResourceIcon")
+    def get_resource_icon(
+        self,
+        format: builtins.str,
+        theme: typing.Optional[builtins.str] = None,
+    ) -> typing.Optional[builtins.str]:
+        '''(experimental) Gets the resource specific icon for the resource.
+
+        :param format: - The format of icon.
+        :param theme: - Optional theme.
+
+        :return: Returns relative asset icon path or undefined if does not have resource icon
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__56b9769af333c872e7ea08a5f5690799f8195f667629e19e4f1a15de3a59f428)
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getResourceIcon", [format, theme]))
@@ -1158,7 +1262,7 @@ class AwsResource(
     def get_service_icon(
         self,
         format: builtins.str,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> typing.Optional[builtins.str]:
         '''(experimental) Gets the service icon for the resource.
 
@@ -1174,7 +1278,7 @@ class AwsResource(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsResource.get_service_icon)
+            type_hints = typing.get_type_hints(_typecheckingstub__a3ee7fac110372279c8a76096ecda3a485aaf9ef46c70a5db8471166c7c73615)
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "getServiceIcon", [format, theme]))
@@ -1183,7 +1287,7 @@ class AwsResource(
     def icon(
         self,
         format: builtins.str,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> typing.Optional[builtins.str]:
         '''(experimental) Gets the best icon match for the resource following the order of: 1.
 
@@ -1199,7 +1303,7 @@ class AwsResource(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsResource.icon)
+            type_hints = typing.get_type_hints(_typecheckingstub__4b0e5dad5a31be1d9e177c837fd05a16d2e2829c25fdac80ef5354cbaed60290)
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "icon", [format, theme]))
@@ -1276,7 +1380,7 @@ class AwsService(
         :throws: Error if service not found
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsService.find_service)
+            type_hints = typing.get_type_hints(_typecheckingstub__b1859c11852030e152876d533ce1abdac7f8f8cea186b45f41182c3fa9756b07)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(typing.Optional["AwsService"], jsii.sinvoke(cls, "findService", [value]))
 
@@ -1293,7 +1397,7 @@ class AwsService(
         :throws: Error is service not found
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsService.get_service)
+            type_hints = typing.get_type_hints(_typecheckingstub__3e0e93ad1e1e794823a49f4f056e0e846eb9125966d29b66ec07ce4cf09bfb5d)
             check_type(argname="argument cfn_service", value=cfn_service, expected_type=type_hints["cfn_service"])
         return typing.cast("AwsService", jsii.sinvoke(cls, "getService", [cfn_service]))
 
@@ -1309,7 +1413,7 @@ class AwsService(
     def icon(
         self,
         format: builtins.str,
-        theme: typing.Optional[_ThemesEnum_7a7c4e43] = None,
+        theme: typing.Optional[builtins.str] = None,
     ) -> typing.Optional[builtins.str]:
         '''(experimental) Get relative asset icon for the service for a given format and optional theme.
 
@@ -1321,7 +1425,7 @@ class AwsService(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsService.icon)
+            type_hints = typing.get_type_hints(_typecheckingstub__49d481428ba15f0268ec038b85ea45e981dbc43a801a439f8af1c52d344bdd10)
             check_type(argname="argument format", value=format, expected_type=type_hints["format"])
             check_type(argname="argument theme", value=theme, expected_type=type_hints["theme"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "icon", [format, theme]))
@@ -1411,6 +1515,146 @@ class AwsService(
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pricingServiceCode"))
 
 
+@jsii.data_type(
+    jsii_type="@aws-prototyping-sdk/aws-arch.ParsedAssetKey",
+    jsii_struct_bases=[],
+    name_mapping={
+        "asset_key": "assetKey",
+        "basename": "basename",
+        "category": "category",
+        "instance_type": "instanceType",
+        "iot_thing": "iotThing",
+        "resource": "resource",
+        "service": "service",
+    },
+)
+class ParsedAssetKey:
+    def __init__(
+        self,
+        *,
+        asset_key: builtins.str,
+        basename: builtins.str,
+        category: builtins.str,
+        instance_type: typing.Optional[builtins.str] = None,
+        iot_thing: typing.Optional[builtins.str] = None,
+        resource: typing.Optional[builtins.str] = None,
+        service: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''(experimental) Parsed asset key.
+
+        :param asset_key: (experimental) Reference to the full key that was parsed.
+        :param basename: (experimental) The last segment of the key (which is the nested icon). For instances and things this includes the dir prefix.
+        :param category: (experimental) Category id.
+        :param instance_type: (experimental) The instance type if key is for an ec2 instance.
+        :param iot_thing: (experimental) The iot thing if key is for an iot thing.
+        :param resource: (experimental) Resource id if key is for a resource.
+        :param service: (experimental) Service id if key is partitioned by resource.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__cca106a5891557774126d86f9ab475cdbe2be258cad9d4e3b1ad7db3d9372142)
+            check_type(argname="argument asset_key", value=asset_key, expected_type=type_hints["asset_key"])
+            check_type(argname="argument basename", value=basename, expected_type=type_hints["basename"])
+            check_type(argname="argument category", value=category, expected_type=type_hints["category"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument iot_thing", value=iot_thing, expected_type=type_hints["iot_thing"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "asset_key": asset_key,
+            "basename": basename,
+            "category": category,
+        }
+        if instance_type is not None:
+            self._values["instance_type"] = instance_type
+        if iot_thing is not None:
+            self._values["iot_thing"] = iot_thing
+        if resource is not None:
+            self._values["resource"] = resource
+        if service is not None:
+            self._values["service"] = service
+
+    @builtins.property
+    def asset_key(self) -> builtins.str:
+        '''(experimental) Reference to the full key that was parsed.
+
+        :stability: experimental
+        '''
+        result = self._values.get("asset_key")
+        assert result is not None, "Required property 'asset_key' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def basename(self) -> builtins.str:
+        '''(experimental) The last segment of the key (which is the nested icon).
+
+        For instances and things this includes the dir prefix.
+
+        :stability: experimental
+        '''
+        result = self._values.get("basename")
+        assert result is not None, "Required property 'basename' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def category(self) -> builtins.str:
+        '''(experimental) Category id.
+
+        :stability: experimental
+        '''
+        result = self._values.get("category")
+        assert result is not None, "Required property 'category' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def instance_type(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The instance type if key is for an ec2 instance.
+
+        :stability: experimental
+        '''
+        result = self._values.get("instance_type")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def iot_thing(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The iot thing if key is for an iot thing.
+
+        :stability: experimental
+        '''
+        result = self._values.get("iot_thing")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def resource(self) -> typing.Optional[builtins.str]:
+        '''(experimental) Resource id if key is for a resource.
+
+        :stability: experimental
+        '''
+        result = self._values.get("resource")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def service(self) -> typing.Optional[builtins.str]:
+        '''(experimental) Service id if key is partitioned by resource.
+
+        :stability: experimental
+        '''
+        result = self._values.get("service")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ParsedAssetKey(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 __all__ = [
     "AwsArchitecture",
     "AwsCategory",
@@ -1419,6 +1663,7 @@ __all__ = [
     "AwsDrawioShapeStyle",
     "AwsResource",
     "AwsService",
+    "ParsedAssetKey",
     "aws_arch",
 ]
 
@@ -1426,3 +1671,234 @@ publication.publish()
 
 # Loading modules to ensure their types are registered with the jsii runtime library
 from . import aws_arch
+
+def _typecheckingstub__50cb6e377ace030d7d0fd23b8b75ce7cab047e065aff0f335dd00cc536e0b731(
+    qualified_asset_key: builtins.str,
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__15d698581bce0a553107193aec703873d21ff56d3a1277980fcbac4037de42f7(
+    category: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__62420b3b4e6499da381320d0dffe1ae40fbfba93826daf27b7b9e7a9812533b7(
+    instance_type: builtins.str,
+    format: typing.Optional[builtins.str] = None,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__643e13aebfc6b58e52fa31f8c1461ad88e54493f25b2a511448723eced639c43(
+    instance_type: builtins.str,
+    format: typing.Optional[builtins.str] = None,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ed6a924b8cfa08bf04a82f31554030fb1973ca30c773d78c32679c51b30554c5(
+    cfn_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8104b4fced639cf6dbccebcf36b75834b302371e6ac70e1fc09dacfc0c7671d3(
+    identifier: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__69679a6460ffe74dd94019acc30bcd926f5c390f7b5469015e3db7434076eb84(
+    asset_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__552d38a0aeee02653237862f4fec1793b69ed0bc3bccaba88dd9d8c8a5ade0ca(
+    asset_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9a7e93f3c9b45f20b0f66b8a67bd69838434582f2b9954d1dc836dc586c103ee(
+    svg_asset_path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bf6ff8b962606b7b17ab54feb5db42cfbce8166becc3c94ca2be14691fe2e5c4(
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f69a17317b51c33fb0068a46d7feef91b78aa33a2b43000fb364b396976fc3e5(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ae148133bd9290873b5fcadeb1785d89474cf6a8babeb3b4249a70e923f18893(
+    category_shape: _ShapeNames_b18b2fa9,
+    *,
+    fill_color: builtins.str,
+    font_color: builtins.str,
+    gradient_color: builtins.str,
+    align: builtins.str,
+    aspect: builtins.str,
+    dashed: jsii.Number,
+    font_size: jsii.Number,
+    font_style: typing.Union[builtins.str, jsii.Number],
+    gradient_direction: builtins.str,
+    html: jsii.Number,
+    outline_connect: jsii.Number,
+    stroke_color: builtins.str,
+    vertical_align: builtins.str,
+    vertical_label_position: builtins.str,
+    pointer_event: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__59b952a871d610dd7d5e35974c586091f08905f704b7425d9ce8953c5830a506(
+    resource_shape: _ShapeNames_b18b2fa9,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8c15f9fc8e1d6209bd88b50e8dfebc38c9a2f8e97f9ad58c1c05728286593464(
+    service_shape: _ShapeNames_b18b2fa9,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b919eb9ba02a70d639eb21b33dcab74c41350024fbd48ce9c86f21461f99f6d7(
+    *,
+    align: builtins.str,
+    aspect: builtins.str,
+    dashed: jsii.Number,
+    font_size: jsii.Number,
+    font_style: typing.Union[builtins.str, jsii.Number],
+    gradient_direction: builtins.str,
+    html: jsii.Number,
+    outline_connect: jsii.Number,
+    stroke_color: builtins.str,
+    vertical_align: builtins.str,
+    vertical_label_position: builtins.str,
+    pointer_event: typing.Optional[jsii.Number] = None,
+    fill_color: builtins.str,
+    font_color: builtins.str,
+    gradient_color: builtins.str,
+    res_icon: _ShapeNames_b18b2fa9,
+    shape: _DrawioAws4ParentShapes_a140e9a5,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0557897d78e40b40ed7072ae513a2fc9ce846dd39b11d3011e4a2f9fb46ddf46(
+    *,
+    align: builtins.str,
+    aspect: builtins.str,
+    dashed: jsii.Number,
+    font_size: jsii.Number,
+    font_style: typing.Union[builtins.str, jsii.Number],
+    gradient_direction: builtins.str,
+    html: jsii.Number,
+    outline_connect: jsii.Number,
+    stroke_color: builtins.str,
+    vertical_align: builtins.str,
+    vertical_label_position: builtins.str,
+    pointer_event: typing.Optional[jsii.Number] = None,
+    fill_color: builtins.str,
+    font_color: builtins.str,
+    gradient_color: builtins.str,
+    shape: _ShapeNames_b18b2fa9,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__443f82bc75854974ef25affe3c77395efc6eafc27d3e89b2b90094ce7f85651e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c74598595ef87eb3d32bc607c61c8ff2ee5cdea295c85f48b84e2deabd2d34b0(
+    cfn_resource_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bbaa927bc3fbe72a481a61f7b9d4f4189cc6b988530ea58b37bb4a085a50c557(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d91c975bb6d0cf335b8a7e464ecee297e8ca1409c582dafcf7b6a6233c7813e9(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__56b9769af333c872e7ea08a5f5690799f8195f667629e19e4f1a15de3a59f428(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a3ee7fac110372279c8a76096ecda3a485aaf9ef46c70a5db8471166c7c73615(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4b0e5dad5a31be1d9e177c837fd05a16d2e2829c25fdac80ef5354cbaed60290(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b1859c11852030e152876d533ce1abdac7f8f8cea186b45f41182c3fa9756b07(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3e0e93ad1e1e794823a49f4f056e0e846eb9125966d29b66ec07ce4cf09bfb5d(
+    cfn_service: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__49d481428ba15f0268ec038b85ea45e981dbc43a801a439f8af1c52d344bdd10(
+    format: builtins.str,
+    theme: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cca106a5891557774126d86f9ab475cdbe2be258cad9d4e3b1ad7db3d9372142(
+    *,
+    asset_key: builtins.str,
+    basename: builtins.str,
+    category: builtins.str,
+    instance_type: typing.Optional[builtins.str] = None,
+    iot_thing: typing.Optional[builtins.str] = None,
+    resource: typing.Optional[builtins.str] = None,
+    service: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
